@@ -13,46 +13,50 @@ class Moment(MutableDate):
     """A class to abstract date difficulties."""
 
     def __init__(self, *args):
-        if args:
-            date, formula = parse_date_and_formula(*args)
-        else:
-            date, formula = (None, None)
+        date, formula = parse_date_and_formula(*args)
         self._date = date
         self._formula = formula
 
-    def now(self):
+    @classmethod
+    def now(cls):
         """Create a moment with the current datetime."""
-        self._date = datetime.now()
-        self._formula = "%Y-%m-%d"
-        return self
+        date = datetime.now()
+        formula = "%Y-%m-%d"
+        return cls(date, formula)
 
-    def utc(self, *args):
+    @classmethod
+    def utc(cls, *args):
         """Create a moment from a UTC date."""
         date, formula = parse_date_and_formula(*args)
-        self._date = pytz.timezone('UTC').localize(date)
-        self._formula = formula
-        return self
+        date = pytz.timezone("UTC").localize(date)
+        return cls(date, formula)
 
-    def utcnow(self):
+    @classmethod
+    def utcnow(cls):
         """UTC equivalent to now."""
-        self._date = pytz.timezone('UTC').localize(datetime.utcnow())
-        self._formula = "%Y-%m-%d"
-        return self
+        date = pytz.timezone("UTC").localize(datetime.utcnow())
+        formula= "%Y-%m-%d"
+        return cls(date, formula)
 
-    def unix(self, timestamp, utc=False):
+    @classmethod
+    def unix(cls, timestamp, utc=False):
         """Create a date from a Unix timestamp."""
+        # Which function are we using?
         if utc:
-            fromtimestamp = datetime.utcfromtimestamp
+            func = datetime.utcfromtimestamp
         else:
-            fromtimestamp = datetime.fromtimestamp
+            func = datetime.fromtimestamp
         try:
             # Seconds since epoch
-            self._date = fromtimestamp(timestamp)
+            date = func(timestamp)
         except ValueError:
             # Milliseconds since epoch
-            self._date = fromtimestamp(timestamp / 1000)
-        self._formula = "%Y-%m-%d"
-        return self
+            date = func(timestamp / 1000)
+        # Feel like it's crazy this isn't default, but whatever.
+        if utc:
+            date = date.replace(tzinfo=pytz.utc)
+        formula = "%Y-%m-%d"
+        return cls(date, formula)
 
     def locale(self, zone=None):
         """Explicitly set the time zone you want to work with."""
@@ -60,7 +64,7 @@ class Moment(MutableDate):
             self._date = datetime.fromtimestamp(timegm(self._date.timetuple()))
         else:
             try:
-                self._date = pytz.timezone(zone).localize(self._date)
+                self._date = pytz.timezone(zone).normalize(self._date)
             except ValueError:
                 self._date = self._date.replace(tzinfo=pytz.timezone(zone))
         return self
@@ -98,11 +102,13 @@ class Moment(MutableDate):
 
     def clone(self):
         """Return a clone of the current moment."""
-        return Moment(self._date)
+        clone = Moment(self._date)
+        clone._formula = self._formula
+        return clone
 
     def copy(self):
         """Same as clone."""
-        return Moment(self._date)
+        return self.clone()
 
     def __repr__(self):
         if self._date is not None:
