@@ -4,7 +4,14 @@ Where the magic happens.
 
 import calendar
 from datetime import datetime, timedelta
+import pytz
 
+from .utils import _iteritems
+
+
+# ----------------------------------------------------------------------------
+# Utilities
+# ----------------------------------------------------------------------------
 
 def add_month(date, number):
     """Add a number of months to a date."""
@@ -20,12 +27,16 @@ def subtract_month(date, number):
 
 def update_month(date, month):
     """Create a new date with a modified number of months."""
-    year = date.year + month / 12
+    year = date.year + int(month / 12)
     month = month % 12 + 1
     day = min(date.day, calendar.monthrange(year, month)[1])
     return date.replace(year=year, month=month, day=day)
 
 
+# ----------------------------------------------------------------------------
+# Main functionality
+# ----------------------------------------------------------------------------
+
 class MutableDate(object):
     """Incapsulate mutable dates in one class."""
 
@@ -35,7 +46,7 @@ class MutableDate(object):
     def add(self, key=None, amount=None, **kwds):
         """Add time to the original moment."""
         if not key and not amount and len(kwds):
-            for k, v in kwds.iteritems():
+            for k, v in _iteritems(kwds):
                 self.add(k, v)
         if key == 'years' or key == 'year':
             self._date = add_month(self._date, amount * 12)
@@ -64,7 +75,7 @@ class MutableDate(object):
     def subtract(self, key=None, amount=None, **kwds):
         """Subtract time from the original moment."""
         if not key and not amount and len(kwds):
-            for k, v in kwds.iteritems():
+            for k, v in _iteritems(kwds):
                 self.subtract(k, v)
         if key == 'years' or key == 'year':
             self._date = subtract_month(self._date, amount * 12)
@@ -88,7 +99,7 @@ class MutableDate(object):
 
     def replace(self, **kwds):
         """A Pythonic way to replace various date attributes."""
-        for key, value in kwds.iteritems():
+        for key, value in _iteritems(kwds):
             if key == 'years' or key == 'year':
                 self._date = self._date.replace(year=value)
             elif key == 'months' or key == 'month':
@@ -110,13 +121,17 @@ class MutableDate(object):
     def epoch(self, rounding=True, milliseconds=False):
         """Milliseconds since epoch."""
         zero = datetime.utcfromtimestamp(0)
-        delta = self._date - zero
+        try:
+            delta = self._date - zero
+        except TypeError:
+            zero = zero.replace(tzinfo=pytz.utc)
+            delta = self._date - zero
         seconds = delta.total_seconds()
         if rounding:
             seconds = round(seconds)
         if milliseconds:
             seconds *= 1000
-        return seconds
+        return int(seconds)
 
     def _weekday(self, number):
         """Mutate the original moment by changing the day of the week."""
